import { useEffect, useRef, useState } from 'react'
import { useDispatch } from 'react-redux'
import { setQuery } from './app/searchSlice'
import { setShowName } from './app/displaySlice'
import { IconList } from './IconList'
// import './App.css'

function App() {
	const inputSearch = useRef()
	const checkShowName = useRef()
	const dispatch = useDispatch()
	const [currentQuery, setCurrentQuery] = useState(window.location.hash.replace("#", "") || "")

	function queryOnChange () {
		let query = inputSearch.current.value
		query = query.replace(/[^a-zA-Z0-9\- ]/, "")

		if (query == '') {
			history.pushState('', '', '#')
		}

		setCurrentQuery(query)
		dispatch(setQuery(query))
	}

	function clearQuery () {
		inputSearch.current.value = ""
		queryOnChange()
	}

	function showNameOnChange () {
		dispatch(setShowName(checkShowName.current.checked))
	}

	function confirmKeyword (e) {
		if (e.key === 'Enter') {
			history.pushState('', '', '#' + inputSearch.current.value)
			inputSearch.current.blur()
		}
	}

	const handleHashChange = (e) => {
		// console.log(e)
		inputSearch.current.value = window.location.hash.replace("#", "")
		queryOnChange()
	};

	useEffect(() => {
		inputSearch.current.focus()
		queryOnChange()

		window.addEventListener('hashchange', handleHashChange)
		return () => {
			window.removeEventListener('hashchange', handleHashChange)
		}
	})

	return (
		<>
			<div className="pixel-input">
				<input type='text' id='search' ref={ inputSearch } onChange={ queryOnChange } onKeyDown={ confirmKeyword } value={ currentQuery } placeholder="Search an icon — try 'animal', 'fruit', 'logo', 'ui' or 'red'" autoComplete='no' />
				{
					currentQuery == '' ? '' : <button id='btn-clear-search' onClick={ clearQuery }>x</button>
				}
			</div>
			<div id='display-options'>
				<input type="checkbox" name="checkShowName" ref={ checkShowName } onChange={ showNameOnChange } id='checkShowName' />
				<label htmlFor="checkShowName">Display icon names</label>
			</div>
			<IconList></IconList>
		</>
	)
}

export default App
